//
//  AppDelegate.m
//  Zippy
//
//  Created by Brian Moakley on 5/20/14.
//  Copyright (c) 2014 Razeware. All rights reserved.
//

#import "AppDelegate.h"
#import "SSZipArchive.h"

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions
{
    // Override point for customization after application launch.

    NSFileManager * fileManager = [NSFileManager defaultManager];
    NSString * zipFilePath = [[NSBundle mainBundle] pathForResource:@"bundle" ofType:@"zip"];
    NSString * tempString = NSTemporaryDirectory();
    NSURL * tempDirectory = [NSURL fileURLWithPath:tempString];
    NSError * error = nil;
    NSURL * documentDirectory = [fileManager URLForDirectory:NSDocumentDirectory inDomain:NSUserDomainMask appropriateForURL:nil create:NO error:&error];
    
    [SSZipArchive unzipFileAtPath:zipFilePath toDestination:NSTemporaryDirectory()];
    
    NSURL * jpgDirectory = [documentDirectory URLByAppendingPathComponent:@"jpg" isDirectory:YES];
    NSURL * pngDirectory = [documentDirectory URLByAppendingPathComponent:@"png" isDirectory:YES];
    NSURL * libraryDirectory = [fileManager URLForDirectory:NSLibraryDirectory inDomain:NSUserDomainMask appropriateForURL:nil create:NO error:&error];
    
    [fileManager createDirectoryAtURL:jpgDirectory withIntermediateDirectories:NO attributes:nil error:&error];
    [fileManager createDirectoryAtURL:pngDirectory withIntermediateDirectories:NO attributes:nil error:&error];
    
    NSArray * files = [fileManager contentsOfDirectoryAtURL:tempDirectory includingPropertiesForKeys:nil options:NSDirectoryEnumerationSkipsHiddenFiles error:&error];
    
    if (files)
    {
        NSError * anotherError = nil;
        for (NSURL * fileUrl in files)
        {
            NSString * extension = [fileUrl pathExtension];
            if ([extension isEqualToString:@"png"])
            {
                [fileManager moveItemAtURL:fileUrl toURL:pngDirectory error:&anotherError];
            }
            if ([extension isEqualToString:@"jpg"])
            {
                NSString *filename = [fileUrl lastPathComponent];
                NSURL * newPath = [jpgDirectory URLByAppendingPathComponent:filename isDirectory:NO];
                
                [fileManager moveItemAtURL:fileUrl toURL:newPath error:&anotherError];
            }
            if ([extension isEqualToString:@"txt"])
            {
                [fileManager moveItemAtURL:fileUrl toURL:libraryDirectory error:&anotherError];
            }
            
        }
    }
    else
    {
        NSLog(@"Bad things are afoot: %@", error);
    }
    
    return YES;
}
							
- (void)applicationWillResignActive:(UIApplication *)application
{
    // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
    // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
}

- (void)applicationDidEnterBackground:(UIApplication *)application
{
    // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later. 
    // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
}

- (void)applicationWillEnterForeground:(UIApplication *)application
{
    // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
}

- (void)applicationDidBecomeActive:(UIApplication *)application
{
    // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
}

- (void)applicationWillTerminate:(UIApplication *)application
{
    // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
}

@end
